@@ -2,6 +2,11 @@
 Code that is necessary for supporting older Django versions
 '''
 
+try:
+    from django.apps.config import get_model
+except ImportError:  # Django < 1.8
+    from django.db.models import get_model
+
 
 def import_by_path(dotted_path, error_prefix=''):
     """
